==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Tarkistus on melkein valmis, kiitos kärsivällisyydestäsi</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Valmistellaan</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Joitakin virheitä tarkistettu</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Siirry työpöydälle</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Järjestelmäsi on päivitetty onnistuneesti</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Nykyinen versio:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Näytä lokit</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Päivitykset onnistuivat</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Tietokoneesi käynnistyy pian uudelleen %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Tietokoneesi sammutetaan pian %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Automaattinen käynnistys uudelleen epäonnistui. Käynnistä tietokone valikosta uudelleen.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Automaattinen sammutus epäonnistui. Sammuta tietokone valikosta.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Piilota lokit</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Päivitys epäonnistui</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Tuntematon virhe</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Varmuuskopio epäonnistui</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Järjestelmän varmuuskopio ei onnistunut. Jos jatkat päivityksiä, et voi palata takaisin vanhaan järjestelmään.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Ei riittävästi levytilaa. Puhdista levytilaa ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Yhteys varmistuksen palveluihin epäonnistui. Tarkista ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Yhteys päivityspalveluihin epäonnistui. Tarkista ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Riippuvuudet virhe</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG virhe</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Varmista uudelleen</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Suorita päivitys</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Siirry työpöydälle</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Valmistellaan päivityksiä…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Älä sammutta virtaa päivityksiä asentaessa. Järjestelmäsi voi vaurioitua.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-update/translations/dde-update_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Tarkistus on melkein valmis, kiitos kärsivällisyydestäsi</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Valmistellaan</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Joitakin virheitä tarkistettu</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Siirry työpöydälle</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Järjestelmäsi on päivitetty onnistuneesti</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Nykyinen versio:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Päivitykset onnistuivat</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Tietokoneesi käynnistyy pian uudelleen %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Tietokoneesi sammutetaan pian %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Automaattinen käynnistys uudelleen epäonnistui. Käynnistä tietokone valikosta uudelleen.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Automaattinen sammutus epäonnistui. Sammuta tietokone valikosta.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Näytä päivityslokit</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Kutista päivityslokit</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Loki on viety työpöydälle</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Lokin vienti epäonnistui, yritä uudelleen</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Päivitys epäonnistui</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Tuntematon virhe</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Varmuuskopio epäonnistui</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Järjestelmän varmuuskopio ei onnistunut. Jos jatkat päivityksiä, et voi palata takaisin vanhaan järjestelmään.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Ei riittävästi levytilaa. Puhdista levytilaa ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Yhteys varmistuksen palveluihin epäonnistui. Tarkista ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Yhteys päivityspalveluihin epäonnistui. Tarkista ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Riippuvuudet virhe</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG virhe</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Varmista uudelleen</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Suorita päivitys</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Siirry työpöydälle</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Valmistellaan päivityksiä…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Älä sammutta virtaa päivityksiä asentaessa. Järjestelmäsi voi vaurioitua.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Näytä päivityslokit</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Kutista päivityslokit</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>päivitysloki</translation>
    </message>
</context>
</TS>
